==> darcs-2.18.1-3-riscv64.pkg.tar.zst: usr/share/haskell/register/darcs.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 darcs
version:              2.18.1
visibility:           public
id:                   darcs-2.18.1-CzuTWbt1GTbbJty6p1NUu
key:                  darcs-2.18.1-CzuTWbt1GTbbJty6p1NUu
license:              GPL-2.0-or-later
maintainer:           <darcs-devel@darcs.net>
author:               David Roundy <droundy@darcs.net>, <darcs-devel@darcs.net>
stability:            Experimental
homepage:             http://darcs.net/
synopsis:             a distributed, interactive, smart revision control system
description:
    Darcs is a free, open source revision control
    system. It is:

    * Distributed: Darcs was one of the first revision control
    systems in which every user has access to the full command
    set, removing boundaries between server and client or
    committer and non-committers.

    * Interactive: Darcs is easy to learn and efficient to use
    because it asks you questions in response to simple
    commands, giving you choices in your work flow. You can
    choose to record one change in a file, while ignoring
    another. As you update from upstream, you can review each
    patch, picking and choosing which patches are appropriate.

    * Smart: Darcs is different from most revision control
    systems in that it is based on the notion of change (or
    patch), rather than version. An underlying algebra of
    patches determines whether changes can be re-ordered. The
    laws of this algebra guarantee that the result of merging
    depends only on the final set of patches applied in a
    repository and not on their order.

    * Simple: As a consequence, Darcs offers a conceptually
    simpler view of the state of a repository: it is given by
    the set of patches it contains. Pulling and pushing
    patches merely transfers them from one set to another. So
    called "cherry-picking" is the default mode of operation,
    and it fully preserves the identity of patches.

category:             Development
abi:                  ce5cd2b5653aa46751b274cf6caabb74
exposed:              True
exposed-modules:
    Darcs.Patch Darcs.Patch.Annotate Darcs.Patch.Annotate.Class
    Darcs.Patch.Apply Darcs.Patch.ApplyMonad Darcs.Patch.Bracketed
    Darcs.Patch.Bundle Darcs.Patch.Choices Darcs.Patch.Commute
    Darcs.Patch.CommuteFn Darcs.Patch.CommuteNoConflicts
    Darcs.Patch.Conflict Darcs.Patch.Debug Darcs.Patch.Depends
    Darcs.Patch.Effect Darcs.Patch.FileHunk Darcs.Patch.Format
    Darcs.Patch.FromPrim Darcs.Patch.Ident Darcs.Patch.Index.Monad
    Darcs.Patch.Index.Types Darcs.Patch.Info Darcs.Patch.Inspect
    Darcs.Patch.Invert Darcs.Patch.Invertible Darcs.Patch.Match
    Darcs.Patch.Merge Darcs.Patch.Named Darcs.Patch.Object
    Darcs.Patch.PatchInfoAnd Darcs.Patch.Permutations Darcs.Patch.Prim
    Darcs.Patch.Prim.Canonize Darcs.Patch.Prim.Class
    Darcs.Patch.Prim.Coalesce Darcs.Patch.Prim.FileUUID
    Darcs.Patch.Prim.FileUUID.Apply Darcs.Patch.Prim.FileUUID.Coalesce
    Darcs.Patch.Prim.FileUUID.Commute Darcs.Patch.Prim.FileUUID.Core
    Darcs.Patch.Prim.FileUUID.Details
    Darcs.Patch.Prim.FileUUID.ObjectMap Darcs.Patch.Prim.FileUUID.Read
    Darcs.Patch.Prim.FileUUID.Show Darcs.Patch.Prim.Named
    Darcs.Patch.Prim.V1 Darcs.Patch.Prim.V1.Apply
    Darcs.Patch.Prim.V1.Coalesce Darcs.Patch.Prim.V1.Commute
    Darcs.Patch.Prim.V1.Core Darcs.Patch.Prim.V1.Details
    Darcs.Patch.Prim.V1.Mangle Darcs.Patch.Prim.V1.Read
    Darcs.Patch.Prim.V1.Show Darcs.Patch.Prim.WithName
    Darcs.Patch.Progress Darcs.Patch.Read Darcs.Patch.Rebase.Change
    Darcs.Patch.Rebase.Fixup Darcs.Patch.Rebase.Legacy.Item
    Darcs.Patch.Rebase.Legacy.Wrapped Darcs.Patch.Rebase.Name
    Darcs.Patch.Rebase.PushFixup Darcs.Patch.Rebase.Suspended
    Darcs.Patch.RegChars Darcs.Patch.Repair Darcs.Patch.RepoPatch
    Darcs.Patch.Set Darcs.Patch.Show Darcs.Patch.Split
    Darcs.Patch.Summary Darcs.Patch.SummaryData
    Darcs.Patch.TokenReplace Darcs.Patch.TouchesFiles
    Darcs.Patch.Unwind Darcs.Patch.V1 Darcs.Patch.V1.Apply
    Darcs.Patch.V1.Commute Darcs.Patch.V1.Core Darcs.Patch.V1.Prim
    Darcs.Patch.V1.Read Darcs.Patch.V1.Show Darcs.Patch.V1.Viewing
    Darcs.Patch.V2 Darcs.Patch.V2.Non Darcs.Patch.V2.Prim
    Darcs.Patch.V2.RepoPatch Darcs.Patch.V3 Darcs.Patch.V3.Contexted
    Darcs.Patch.V3.Core Darcs.Patch.V3.Resolution Darcs.Patch.Viewing
    Darcs.Patch.Witnesses.Eq Darcs.Patch.Witnesses.Maybe
    Darcs.Patch.Witnesses.Ordered Darcs.Patch.Witnesses.Sealed
    Darcs.Patch.Witnesses.Show Darcs.Patch.Witnesses.Unsafe
    Darcs.Patch.Witnesses.WZipper Darcs.Prelude Darcs.Repository
    Darcs.Repository.ApplyPatches Darcs.Repository.Clone
    Darcs.Repository.Create Darcs.Repository.Diff
    Darcs.Repository.Flags Darcs.Repository.Format
    Darcs.Repository.Hashed Darcs.Repository.Identify
    Darcs.Repository.InternalTypes Darcs.Repository.Inventory
    Darcs.Repository.Inventory.Format Darcs.Repository.Job
    Darcs.Repository.Match Darcs.Repository.Merge Darcs.Repository.Old
    Darcs.Repository.Packs Darcs.Repository.PatchIndex
    Darcs.Repository.Paths Darcs.Repository.Pending
    Darcs.Repository.Prefs Darcs.Repository.Pristine
    Darcs.Repository.Rebase Darcs.Repository.Repair
    Darcs.Repository.Resolution Darcs.Repository.State
    Darcs.Repository.Transaction Darcs.Repository.Traverse
    Darcs.Repository.Unrevert Darcs.Repository.Working
    Darcs.Test.TestOnly Darcs.UI.ApplyPatches Darcs.UI.Commands
    Darcs.UI.Commands.Add Darcs.UI.Commands.Amend
    Darcs.UI.Commands.Annotate Darcs.UI.Commands.Apply
    Darcs.UI.Commands.Clone Darcs.UI.Commands.Convert
    Darcs.UI.Commands.Convert.Darcs2 Darcs.UI.Commands.Convert.Export
    Darcs.UI.Commands.Convert.Import Darcs.UI.Commands.Convert.Util
    Darcs.UI.Commands.Diff Darcs.UI.Commands.Dist
    Darcs.UI.Commands.GZCRCs Darcs.UI.Commands.Help
    Darcs.UI.Commands.Init Darcs.UI.Commands.Log
    Darcs.UI.Commands.MarkConflicts Darcs.UI.Commands.Move
    Darcs.UI.Commands.Optimize Darcs.UI.Commands.Pull
    Darcs.UI.Commands.Push Darcs.UI.Commands.Rebase
    Darcs.UI.Commands.Record Darcs.UI.Commands.Remove
    Darcs.UI.Commands.Repair Darcs.UI.Commands.Replace
    Darcs.UI.Commands.Revert Darcs.UI.Commands.Rollback
    Darcs.UI.Commands.Send Darcs.UI.Commands.SetPref
    Darcs.UI.Commands.Show Darcs.UI.Commands.ShowAuthors
    Darcs.UI.Commands.ShowContents Darcs.UI.Commands.ShowDependencies
    Darcs.UI.Commands.ShowFiles Darcs.UI.Commands.ShowIndex
    Darcs.UI.Commands.ShowPatchIndex Darcs.UI.Commands.ShowRepo
    Darcs.UI.Commands.ShowTags Darcs.UI.Commands.Tag
    Darcs.UI.Commands.Test Darcs.UI.Commands.Test.Impl
    Darcs.UI.Commands.TransferMode Darcs.UI.Commands.Unrecord
    Darcs.UI.Commands.Unrevert Darcs.UI.Commands.Util
    Darcs.UI.Commands.WhatsNew Darcs.UI.Completion Darcs.UI.Defaults
    Darcs.UI.Email Darcs.UI.External Darcs.UI.Flags Darcs.UI.Options
    Darcs.UI.Options.All Darcs.UI.Options.Core Darcs.UI.Options.Flags
    Darcs.UI.Options.Iso Darcs.UI.Options.Markdown
    Darcs.UI.Options.Matching Darcs.UI.Options.Util
    Darcs.UI.PatchHeader Darcs.UI.PrintPatch Darcs.UI.Prompt
    Darcs.UI.RunCommand Darcs.UI.RunHook Darcs.UI.SelectChanges
    Darcs.UI.TestChanges Darcs.UI.TheCommands Darcs.UI.Usage
    Darcs.Util.AtExit Darcs.Util.ByteString Darcs.Util.Cache
    Darcs.Util.CommandLine Darcs.Util.Compat Darcs.Util.DateMatcher
    Darcs.Util.DateTime Darcs.Util.Diff Darcs.Util.Diff.Myers
    Darcs.Util.Diff.Patience Darcs.Util.Encoding Darcs.Util.English
    Darcs.Util.Exception Darcs.Util.Exec Darcs.Util.File
    Darcs.Util.Global Darcs.Util.Graph Darcs.Util.HTTP Darcs.Util.Hash
    Darcs.Util.Index Darcs.Util.IndexedMonad Darcs.Util.IsoDate
    Darcs.Util.Lock Darcs.Util.Parser Darcs.Util.Path
    Darcs.Util.Printer Darcs.Util.Printer.Color Darcs.Util.Progress
    Darcs.Util.Prompt Darcs.Util.Ratified Darcs.Util.Regex
    Darcs.Util.Show Darcs.Util.SignalHandler Darcs.Util.Ssh
    Darcs.Util.Tree Darcs.Util.Tree.Hashed Darcs.Util.Tree.Monad
    Darcs.Util.Tree.Plain Darcs.Util.URL Darcs.Util.ValidHash
    Darcs.Util.Workaround

hidden-modules:       Version
import-dirs:          /usr/lib/ghc-9.2.8/site-local/darcs-2.18.1
library-dirs:         /usr/lib/ghc-9.2.8/site-local/darcs-2.18.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/darcs
hs-libraries:         HSdarcs-2.18.1-CzuTWbt1GTbbJty6p1NUu
depends:
    array-0.5.4.0 async-2.2.5-b1lsUdcpsoF4yB7f3qI00
    attoparsec-0.14.4-l6gpYVAuXa4krkAJlMwbn base-4.16.4.0
    base16-bytestring-1.0.2.0-KWjk12Kc0JO2Mp5RJvDvOx binary-0.8.9.0
    bytestring-0.11.4.0 conduit-1.3.5-9fqCSsgtXVG2zpv5ZVEi4s
    constraints-0.13.4-ACnviuVki2ys6bePKbSMI containers-0.6.5.1
    cryptonite-0.30-2G7emN3aUjLCPswZX3R9DV
    data-ordlist-0.4.7.0-8fzfDa3tsIUEkVn0I0u3f directory-1.3.6.2
    exceptions-0.10.4 fgl-5.8.2.0-Cgtt5MzQZavWByMvy2dgH
    filepath-1.4.2.2 hashable-1.4.3.0-7566tBsT9J8EFScR3Tb2Bc
    haskeline-0.8.2 html-1.0.1.2-1i34Da0w7lMJxSeIv8hoxf
    http-conduit-2.3.8.3-1nsQ6LY8l6ZCKHc2yiI82m
    http-types-0.12.4-B3znMwHTe3dL304Bd3IJgZ
    memory-0.18.0-Hvum6HaH78UJG59LYyNLK1
    mmap-0.5.9-Ev5kK7GQQYl5y5LE8RvEAs mtl-2.2.2
    network-3.1.4.0-IeiVJWXSaeWHp5XfJw1SH3
    network-uri-2.6.4.2-7MCOm8Y28rz5TXDrjTesz4
    old-time-1.1.0.4-Dlc8YwGlkPi2Y3VNXkrOFg parsec-3.1.15.0
    process-1.6.16.0 regex-applicative-0.3.4-Kt5xnzODT36H43MhNmNOQu
    regex-base-0.94.0.2-6On48UZuN5IJxnL3aRqiWN
    regex-tdfa-1.3.2.2-G7ufGPI8BXGB521OJBI0lU stm-2.5.0.2
    strict-identity-0.1.0.0-AqkUMYJvDUhBWyYZOCRghU
    tar-0.5.1.1-5EYCQaVq6PDAolrLcyZluX
    temporary-1.3-7m2Oh4fRk7W729IUmkQcQs
    terminal-size-0.3.4-7GJNKkuDjwr8c9rYP2Bu9E terminfo-0.4.1.5
    text-1.2.5.0 time-1.11.1.1 tls-1.8.0-H8NsUaBoeZf4tUx17BPTZh
    transformers-0.5.6.2 unix-2.7.2.2
    unix-compat-0.7.1-CUEzLwxYcvzKLG20I3UG32
    utf8-string-1.0.2-9i4m1tpDbmh81tMCrQ25jI
    vector-0.13.1.0-HyaXkpW7aOFHhHqdwTfvZq
    zip-archive-0.4.3.2-EJmyfs1qFeh5zU8q2YI3Z5
    zlib-0.6.3.0-KXw1YjlC9QN908pTSJIti

haddock-interfaces:   /usr/share/doc/darcs/html/darcs.haddock
haddock-html:         /usr/share/doc/darcs/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> darcs-2.18.2-13-riscv64.pkg.tar.zst: usr/share/haskell/register/darcs.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 darcs
version:              2.18.2
visibility:           public
id:                   darcs-2.18.2-2NIplhtKRvmCt1QV9O2qJz
key:                  darcs-2.18.2-2NIplhtKRvmCt1QV9O2qJz
license:              GPL-2.0-or-later
maintainer:           <darcs-devel@darcs.net>
author:               David Roundy <droundy@darcs.net>, <darcs-devel@darcs.net>
stability:            Experimental
homepage:             http://darcs.net/
synopsis:             a distributed, interactive, smart revision control system
description:
    Darcs is a free, open source revision control
    system. It is:

    * Distributed: Darcs was one of the first revision control
    systems in which every user has access to the full command
    set, removing boundaries between server and client or
    committer and non-committers.

    * Interactive: Darcs is easy to learn and efficient to use
    because it asks you questions in response to simple
    commands, giving you choices in your work flow. You can
    choose to record one change in a file, while ignoring
    another. As you update from upstream, you can review each
    patch, picking and choosing which patches are appropriate.

    * Smart: Darcs is different from most revision control
    systems in that it is based on the notion of change (or
    patch), rather than version. An underlying algebra of
    patches determines whether changes can be re-ordered. The
    laws of this algebra guarantee that the result of merging
    depends only on the final set of patches applied in a
    repository and not on their order.

    * Simple: As a consequence, Darcs offers a conceptually
    simpler view of the state of a repository: it is given by
    the set of patches it contains. Pulling and pushing
    patches merely transfers them from one set to another. So
    called "cherry-picking" is the default mode of operation,
    and it fully preserves the identity of patches.

category:             Development
abi:                  68970129cd84a8fe573833f3fb8ccbac
exposed:              True
exposed-modules:
    Darcs.Patch Darcs.Patch.Annotate Darcs.Patch.Annotate.Class
    Darcs.Patch.Apply Darcs.Patch.ApplyMonad Darcs.Patch.Bracketed
    Darcs.Patch.Bundle Darcs.Patch.Choices Darcs.Patch.Commute
    Darcs.Patch.CommuteFn Darcs.Patch.CommuteNoConflicts
    Darcs.Patch.Conflict Darcs.Patch.Debug Darcs.Patch.Depends
    Darcs.Patch.Effect Darcs.Patch.FileHunk Darcs.Patch.Format
    Darcs.Patch.FromPrim Darcs.Patch.Ident Darcs.Patch.Index.Monad
    Darcs.Patch.Index.Types Darcs.Patch.Info Darcs.Patch.Inspect
    Darcs.Patch.Invert Darcs.Patch.Invertible Darcs.Patch.Match
    Darcs.Patch.Merge Darcs.Patch.Named Darcs.Patch.Object
    Darcs.Patch.PatchInfoAnd Darcs.Patch.Permutations Darcs.Patch.Prim
    Darcs.Patch.Prim.Canonize Darcs.Patch.Prim.Class
    Darcs.Patch.Prim.Coalesce Darcs.Patch.Prim.FileUUID
    Darcs.Patch.Prim.FileUUID.Apply Darcs.Patch.Prim.FileUUID.Coalesce
    Darcs.Patch.Prim.FileUUID.Commute Darcs.Patch.Prim.FileUUID.Core
    Darcs.Patch.Prim.FileUUID.Details
    Darcs.Patch.Prim.FileUUID.ObjectMap Darcs.Patch.Prim.FileUUID.Read
    Darcs.Patch.Prim.FileUUID.Show Darcs.Patch.Prim.Named
    Darcs.Patch.Prim.V1 Darcs.Patch.Prim.V1.Apply
    Darcs.Patch.Prim.V1.Coalesce Darcs.Patch.Prim.V1.Commute
    Darcs.Patch.Prim.V1.Core Darcs.Patch.Prim.V1.Details
    Darcs.Patch.Prim.V1.Mangle Darcs.Patch.Prim.V1.Read
    Darcs.Patch.Prim.V1.Show Darcs.Patch.Prim.WithName
    Darcs.Patch.Progress Darcs.Patch.Read Darcs.Patch.Rebase.Change
    Darcs.Patch.Rebase.Fixup Darcs.Patch.Rebase.Legacy.Item
    Darcs.Patch.Rebase.Legacy.Wrapped Darcs.Patch.Rebase.Name
    Darcs.Patch.Rebase.PushFixup Darcs.Patch.Rebase.Suspended
    Darcs.Patch.RegChars Darcs.Patch.Repair Darcs.Patch.RepoPatch
    Darcs.Patch.Set Darcs.Patch.Show Darcs.Patch.Split
    Darcs.Patch.Summary Darcs.Patch.SummaryData
    Darcs.Patch.TokenReplace Darcs.Patch.TouchesFiles
    Darcs.Patch.Unwind Darcs.Patch.V1 Darcs.Patch.V1.Apply
    Darcs.Patch.V1.Commute Darcs.Patch.V1.Core Darcs.Patch.V1.Prim
    Darcs.Patch.V1.Read Darcs.Patch.V1.Show Darcs.Patch.V1.Viewing
    Darcs.Patch.V2 Darcs.Patch.V2.Non Darcs.Patch.V2.Prim
    Darcs.Patch.V2.RepoPatch Darcs.Patch.V3 Darcs.Patch.V3.Contexted
    Darcs.Patch.V3.Core Darcs.Patch.V3.Resolution Darcs.Patch.Viewing
    Darcs.Patch.Witnesses.Eq Darcs.Patch.Witnesses.Maybe
    Darcs.Patch.Witnesses.Ordered Darcs.Patch.Witnesses.Sealed
    Darcs.Patch.Witnesses.Show Darcs.Patch.Witnesses.Unsafe
    Darcs.Patch.Witnesses.WZipper Darcs.Prelude Darcs.Repository
    Darcs.Repository.ApplyPatches Darcs.Repository.Clone
    Darcs.Repository.Create Darcs.Repository.Diff
    Darcs.Repository.Flags Darcs.Repository.Format
    Darcs.Repository.Hashed Darcs.Repository.Identify
    Darcs.Repository.InternalTypes Darcs.Repository.Inventory
    Darcs.Repository.Inventory.Format Darcs.Repository.Job
    Darcs.Repository.Match Darcs.Repository.Merge Darcs.Repository.Old
    Darcs.Repository.Packs Darcs.Repository.PatchIndex
    Darcs.Repository.Paths Darcs.Repository.Pending
    Darcs.Repository.Prefs Darcs.Repository.Pristine
    Darcs.Repository.Rebase Darcs.Repository.Repair
    Darcs.Repository.Resolution Darcs.Repository.State
    Darcs.Repository.Transaction Darcs.Repository.Traverse
    Darcs.Repository.Unrevert Darcs.Repository.Working
    Darcs.Test.TestOnly Darcs.UI.ApplyPatches Darcs.UI.Commands
    Darcs.UI.Commands.Add Darcs.UI.Commands.Amend
    Darcs.UI.Commands.Annotate Darcs.UI.Commands.Apply
    Darcs.UI.Commands.Clone Darcs.UI.Commands.Convert
    Darcs.UI.Commands.Convert.Darcs2 Darcs.UI.Commands.Convert.Export
    Darcs.UI.Commands.Convert.Import Darcs.UI.Commands.Convert.Util
    Darcs.UI.Commands.Diff Darcs.UI.Commands.Dist
    Darcs.UI.Commands.GZCRCs Darcs.UI.Commands.Help
    Darcs.UI.Commands.Init Darcs.UI.Commands.Log
    Darcs.UI.Commands.MarkConflicts Darcs.UI.Commands.Move
    Darcs.UI.Commands.Optimize Darcs.UI.Commands.Pull
    Darcs.UI.Commands.Push Darcs.UI.Commands.Rebase
    Darcs.UI.Commands.Record Darcs.UI.Commands.Remove
    Darcs.UI.Commands.Repair Darcs.UI.Commands.Replace
    Darcs.UI.Commands.Revert Darcs.UI.Commands.Rollback
    Darcs.UI.Commands.Send Darcs.UI.Commands.SetPref
    Darcs.UI.Commands.Show Darcs.UI.Commands.ShowAuthors
    Darcs.UI.Commands.ShowContents Darcs.UI.Commands.ShowDependencies
    Darcs.UI.Commands.ShowFiles Darcs.UI.Commands.ShowIndex
    Darcs.UI.Commands.ShowPatchIndex Darcs.UI.Commands.ShowRepo
    Darcs.UI.Commands.ShowTags Darcs.UI.Commands.Tag
    Darcs.UI.Commands.Test Darcs.UI.Commands.Test.Impl
    Darcs.UI.Commands.TransferMode Darcs.UI.Commands.Unrecord
    Darcs.UI.Commands.Unrevert Darcs.UI.Commands.Util
    Darcs.UI.Commands.WhatsNew Darcs.UI.Completion Darcs.UI.Defaults
    Darcs.UI.Email Darcs.UI.External Darcs.UI.Flags Darcs.UI.Options
    Darcs.UI.Options.All Darcs.UI.Options.Core Darcs.UI.Options.Flags
    Darcs.UI.Options.Iso Darcs.UI.Options.Markdown
    Darcs.UI.Options.Matching Darcs.UI.Options.Util
    Darcs.UI.PatchHeader Darcs.UI.PrintPatch Darcs.UI.Prompt
    Darcs.UI.RunCommand Darcs.UI.RunHook Darcs.UI.SelectChanges
    Darcs.UI.TestChanges Darcs.UI.TheCommands Darcs.UI.Usage
    Darcs.Util.AtExit Darcs.Util.ByteString Darcs.Util.Cache
    Darcs.Util.CommandLine Darcs.Util.Compat Darcs.Util.DateMatcher
    Darcs.Util.DateTime Darcs.Util.Diff Darcs.Util.Diff.Myers
    Darcs.Util.Diff.Patience Darcs.Util.Encoding Darcs.Util.English
    Darcs.Util.Exception Darcs.Util.Exec Darcs.Util.File
    Darcs.Util.Global Darcs.Util.Graph Darcs.Util.HTTP Darcs.Util.Hash
    Darcs.Util.Index Darcs.Util.IndexedMonad Darcs.Util.IsoDate
    Darcs.Util.Lock Darcs.Util.Parser Darcs.Util.Path
    Darcs.Util.Printer Darcs.Util.Printer.Color Darcs.Util.Progress
    Darcs.Util.Prompt Darcs.Util.Ratified Darcs.Util.Regex
    Darcs.Util.Show Darcs.Util.SignalHandler Darcs.Util.Ssh
    Darcs.Util.Tree Darcs.Util.Tree.Hashed Darcs.Util.Tree.Monad
    Darcs.Util.Tree.Plain Darcs.Util.URL Darcs.Util.ValidHash
    Darcs.Util.Workaround

hidden-modules:       Version
import-dirs:          /usr/lib/ghc-9.2.8/site-local/darcs-2.18.2
library-dirs:         /usr/lib/ghc-9.2.8/site-local/darcs-2.18.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/darcs
hs-libraries:         HSdarcs-2.18.2-2NIplhtKRvmCt1QV9O2qJz
depends:
    array-0.5.4.0 async-2.2.5-Hxx4nU8aNwh7V1GfZTZX85
    attoparsec-0.14.4-7zFXPvsAeTc17D9FbG47Bq base-4.16.4.0
    base16-bytestring-1.0.2.0-1EKQKfIbtqrKykCu8OdSyV binary-0.8.9.0
    bytestring-0.11.4.0 conduit-1.3.6-6d8V4DJENsC1laAutlfv9x
    constraints-0.13.4-7zdNhBEZCHL204LP1Lqk4K containers-0.6.5.1
    cryptonite-0.30-7YCFiEak3iS4jVbhqnIKep
    data-ordlist-0.4.7.0-8fzfDa3tsIUEkVn0I0u3f directory-1.3.6.2
    exceptions-0.10.4 fgl-5.8.2.0-Eb6xdEigYbA8WAuh82pZJA
    filepath-1.4.2.2 hashable-1.4.4.0-KJ184tiZpE52U0PEHxyV1r
    haskeline-0.8.2 html-1.0.1.2-1i34Da0w7lMJxSeIv8hoxf
    http-conduit-2.3.8.3-KkBMXrBtxP6LrN8a2mfNMZ
    http-types-0.12.4-4jA7skhyc4O1mTcupRz8pv
    memory-0.18.0-Hvum6HaH78UJG59LYyNLK1
    mmap-0.5.9-Ev5kK7GQQYl5y5LE8RvEAs mtl-2.2.2
    network-3.1.4.0-BwapeZNENJRGd3a4t7iBSJ
    network-uri-2.6.4.2-H8R7YZM4iJL108zVnRjrHh
    old-time-1.1.0.4-Dlc8YwGlkPi2Y3VNXkrOFg parsec-3.1.15.0
    process-1.6.16.0 regex-applicative-0.3.4-4NdhEcqn8s47qEMCdmg4NR
    regex-base-0.94.0.2-6On48UZuN5IJxnL3aRqiWN
    regex-tdfa-1.3.2.2-9KQuOdDpiBL9UBsQEK6k8E
    safe-0.3.21-98IVtOx0Wmj8cqPHUtTkEF stm-2.5.0.2
    strict-identity-0.1.0.0-AqkUMYJvDUhBWyYZOCRghU
    tar-0.5.1.1-CmQihJxv27rI4SRTxO9RwD
    temporary-1.3-92h1kCtCGR4FaQHxoGuxwh
    terminal-size-0.3.4-7GJNKkuDjwr8c9rYP2Bu9E terminfo-0.4.1.5
    text-1.2.5.0 time-1.11.1.1 tls-1.8.0-7h7yCI2XUOLCqAd7IRMHCz
    transformers-0.5.6.2 unix-2.7.2.2
    unix-compat-0.7.2-3S8nQVag41zGjHM5MpRJPG
    utf8-string-1.0.2-AQMRv3gsvE14uh4nlO1egX
    vector-0.13.1.0-xP3uH1g3cPFld8g0jCD5r
    zip-archive-0.4.3.2-6oIc3L9nVJJUpVNmPG3PI
    zlib-0.6.3.0-AuZles6iZ6jGNBHTmlcghA

haddock-interfaces:   /usr/share/doc/darcs/html/darcs.haddock
haddock-html:         /usr/share/doc/darcs/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
